pub fn transient_initial_state(spec: &TransientSpec) -> TransientStateExpand description
Build initial state from a spec — flags get their defaults, arguments get their defaults (or empty string).
pub fn transient_initial_state(spec: &TransientSpec) -> TransientStateBuild initial state from a spec — flags get their defaults, arguments get their defaults (or empty string).